@@ -4,7 +4,7 @@ from dataclasses import dataclass
 from starlette.routing import BaseRoute, Mount
 from starlette.routing import Router as StarletteRouter
 
-from xpresso._utils.compat import Protocol
+from xpresso._utils.typing import Protocol
 from xpresso.routing.pathitem import Path
 from xpresso.routing.router import Router as XpressoRouter
 from xpresso.routing.websockets import WebSocketRoute
